
<h1 align="center">
  <br>
  <a href="https://openpecha.org"><img src="https://avatars.githubusercontent.com/u/82142807?s=400&u=19e108a15566f3a1449bafb03b8dd706a72aebcd&v=4" alt="OpenPecha" width="150"></a>
  <br>
</h1>

<!-- Replace with 1-sentence description about what this tool is or does.-->

<h3 align="center"> Package help to transfer annotations from one file to another.</h3>

## Project owner(s)

<!-- Link to the repo owners' github profiles -->

- [@kaldan007](https://github.com/kaldan007)

## Integrations

<!-- Add any intregrations here or delete `- []()` and write None-->

None
## Docs

<!-- Update the link to the docs -->

Read the docs [here](https://wiki.openpecha.org/#/dev/coding-guidelines).
